@@ -15,12 +15,17 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 import ftplib
 import re
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.providers.ftp.hooks.ftp import FTPHook, FTPSHook
 from airflow.sensors.base import BaseSensorOperator
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class FTPSensor(BaseSensorOperator):
@@ -28,25 +33,21 @@ class FTPSensor(BaseSensorOperator):
     Waits for a file or directory to be present on FTP.
 
     :param path: Remote file or directory path
-    :type path: str
     :param fail_on_transient_errors: Fail on all errors,
         including 4xx transient errors. Default True.
-    :type fail_on_transient_errors: bool
     :param ftp_conn_id: The :ref:`ftp connection id <howto/connection:ftp>`
         reference to run the sensor against.
-    :type ftp_conn_id: str
     """
 
-    template_fields = ('path',)
+    template_fields: Sequence[str] = ("path",)
 
     """Errors that are transient in nature, and where action can be retried"""
     transient_errors = [421, 425, 426, 434, 450, 451, 452]
 
     error_code_pattern = re.compile(r"([\d]+)")
 
-    @apply_defaults
     def __init__(
-        self, *, path: str, ftp_conn_id: str = 'ftp_default', fail_on_transient_errors: bool = True, **kwargs
+        self, *, path: str, ftp_conn_id: str = "ftp_default", fail_on_transient_errors: bool = True, **kwargs
     ) -> None:
         super().__init__(**kwargs)
 
@@ -67,15 +68,15 @@ class FTPSensor(BaseSensorOperator):
         except ValueError:
             return e
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: Context) -> bool:
         with self._create_hook() as hook:
-            self.log.info('Poking for %s', self.path)
+            self.log.info("Poking for %s", self.path)
             try:
                 mod_time = hook.get_mod_time(self.path)
-                self.log.info('Found File %s last modified: %s', str(self.path), str(mod_time))
+                self.log.info("Found File %s last modified: %s", str(self.path), str(mod_time))
 
             except ftplib.error_perm as e:
-                self.log.error('Ftp error encountered: %s', str(e))
+                self.log.error("Ftp error encountered: %s", str(e))
                 error_code = self._get_error_code(e)
                 if (error_code != 550) and (
                     self.fail_on_transient_errors or (error_code not in self.transient_errors)
